package com.ruoyi.system.controller;

import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PutMapping;
import com.ruoyi.common.security.utils.SecurityUtils;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.validation.annotation.Validated;
import com.ruoyi.common.core.web.domain.AjaxResult;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.PostMapping;
import com.ruoyi.common.log.enums.BusinessType;
import com.ruoyi.common.log.annotation.Log;
import com.ruoyi.common.core.utils.poi.ExcelUtil;
import javax.servlet.http.HttpServletResponse;
import org.springframework.web.bind.annotation.GetMapping;
import com.ruoyi.common.security.annotation.RequiresPermissions;
import java.util.List;
import com.ruoyi.common.core.web.page.TableDataInfo;
import com.ruoyi.system.api.domain.SysDictType;
import org.springframework.beans.factory.annotation.Autowired;
import com.ruoyi.system.service.ISysDictTypeService;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.core.web.controller.BaseController;

@RestController
@RequestMapping({ "/dict/type" })
public class SysDictTypeController extends BaseController
{
    @Autowired
    private ISysDictTypeService dictTypeService;
    
    @RequiresPermissions({ "system:dict:list" })
    @GetMapping({ "/list" })
    public TableDataInfo list(final SysDictType dictType) {
        this.startPage();
        final List<SysDictType> list = this.dictTypeService.selectDictTypeList(dictType);
        return this.getDataTable((List)list);
    }
    
    @Log(title = "字典类型", businessType = BusinessType.EXPORT)
    @RequiresPermissions({ "system:dict:export" })
    @PostMapping({ "/export" })
    public void export(final HttpServletResponse response, final SysDictType dictType) {
        final List<SysDictType> list = this.dictTypeService.selectDictTypeList(dictType);
        final ExcelUtil<SysDictType> util = (ExcelUtil<SysDictType>)new ExcelUtil((Class)SysDictType.class);
        util.exportExcel(response, (List)list, "字典类型");
    }
    
    @RequiresPermissions({ "system:dict:query" })
    @GetMapping({ "/{dictId}" })
    public AjaxResult getInfo(@PathVariable final Long dictId) {
        return this.success((Object)this.dictTypeService.selectDictTypeById(dictId));
    }
    
    @RequiresPermissions({ "system:dict:add" })
    @Log(title = "字典类型", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@Validated @RequestBody final SysDictType dict) {
        if (!this.dictTypeService.checkDictTypeUnique(dict)) {
            return this.error("新增字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
        dict.setCreateBy(SecurityUtils.getUsername());
        return this.toAjax(this.dictTypeService.insertDictType(dict));
    }
    
    @RequiresPermissions({ "system:dict:edit" })
    @Log(title = "字典类型", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@Validated @RequestBody final SysDictType dict) {
        if (!this.dictTypeService.checkDictTypeUnique(dict)) {
            return this.error("修改字典'" + dict.getDictName() + "'失败，字典类型已存在");
        }
        dict.setUpdateBy(SecurityUtils.getUsername());
        return this.toAjax(this.dictTypeService.updateDictType(dict));
    }
    
    @RequiresPermissions({ "system:dict:remove" })
    @Log(title = "字典类型", businessType = BusinessType.DELETE)
    @DeleteMapping({ "/{dictIds}" })
    public AjaxResult remove(@PathVariable final Long[] dictIds) {
        this.dictTypeService.deleteDictTypeByIds(dictIds);
        return this.success();
    }
    
    @RequiresPermissions({ "system:dict:remove" })
    @Log(title = "字典类型", businessType = BusinessType.CLEAN)
    @DeleteMapping({ "/refreshCache" })
    public AjaxResult refreshCache() {
        this.dictTypeService.resetDictCache();
        return this.success();
    }
    
    @GetMapping({ "/optionselect" })
    public AjaxResult optionselect() {
        final List<SysDictType> dictTypes = this.dictTypeService.selectDictTypeAll();
        return this.success((Object)dictTypes);
    }
}
